@@ -15,10 +15,13 @@
 """Convenience functions for dealing with instance templates."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 from googlecloudsdk.api_lib.compute import alias_ip_range_utils
 from googlecloudsdk.api_lib.compute import constants
 from googlecloudsdk.api_lib.compute import image_utils
+from googlecloudsdk.api_lib.compute import kms_utils
 from googlecloudsdk.api_lib.compute import utils
 from googlecloudsdk.command_lib.compute import scope as compute_scope
 from googlecloudsdk.command_lib.compute.networks.subnets import flags as subnet_flags
@@ -99,8 +102,7 @@ def CreateNetworkInterfaceMessage(
 
 
 def CreateNetworkInterfaceMessages(resources, scope_lister, messages,
-                                   network_interface_arg, region,
-                                   support_network_tier):
+                                   network_interface_arg, region):
   """Create network interface messages.
 
   Args:
@@ -109,7 +111,6 @@ def CreateNetworkInterfaceMessages(resources, scope_lister, messages,
     messages: creates resources.
     network_interface_arg: CLI argument specifying network interfaces.
     region: region of the subnetwork.
-    support_network_tier: indicates if network tier is supported.
   Returns:
     list, items are NetworkInterfaceMessages.
   """
@@ -121,10 +122,7 @@ def CreateNetworkInterfaceMessages(resources, scope_lister, messages,
       if address == '':
         address = EPHEMERAL_ADDRESS
 
-      if support_network_tier:
-        network_tier = interface.get('network-tier', None)
-      else:
-        network_tier = None
+      network_tier = interface.get('network-tier', None)
 
       result.append(CreateNetworkInterfaceMessage(
           resources, scope_lister, messages, interface.get('network', None),
@@ -184,7 +182,7 @@ def CreatePersistentAttachedDiskMessages(messages, disks):
 
 
 def CreatePersistentCreateDiskMessages(client, resources, user_project,
-                                       create_disks):
+                                       create_disks, support_kms=False):
   """Returns a list of AttachedDisk messages.
 
   Args:
@@ -202,6 +200,7 @@ def CreatePersistentCreateDiskMessages(client, resources, user_project,
              * auto-delete - whether disks is deleted when VM is deleted ('yes'
                if True),
              * device-name - device name on VM.
+    support_kms: if KMS is supported
 
   Returns:
     list of API messages for attached disks
@@ -233,6 +232,11 @@ def CreatePersistentCreateDiskMessages(client, resources, user_project,
           image_project=img_project,
           return_image_resource=False)
 
+    disk_key = None
+    if support_kms:
+      disk_key = kms_utils.MaybeGetKmsKeyFromDict(
+          disk, client.messages, disk_key)
+
     create_disk = client.messages.AttachedDisk(
         autoDelete=auto_delete,
         boot=False,
@@ -243,7 +247,8 @@ def CreatePersistentCreateDiskMessages(client, resources, user_project,
             diskSizeGb=disk_size_gb,
             diskType=disk.get('type')),
         mode=mode,
-        type=client.messages.AttachedDisk.TypeValueValuesEnum.PERSISTENT)
+        type=client.messages.AttachedDisk.TypeValueValuesEnum.PERSISTENT,
+        diskEncryptionKey=disk_key)
 
     disks_messages.append(create_disk)
 
@@ -252,8 +257,14 @@ def CreatePersistentCreateDiskMessages(client, resources, user_project,
 
 def CreateDefaultBootAttachedDiskMessage(
     messages, disk_type, disk_device_name, disk_auto_delete, disk_size_gb,
-    image_uri):
+    image_uri, kms_args=None, support_kms=False):
   """Returns an AttachedDisk message for creating a new boot disk."""
+  disk_key = None
+
+  if support_kms:
+    disk_key = kms_utils.MaybeGetKmsKey(
+        kms_args, messages, disk_key, boot_disk_prefix=True)
+
   return messages.AttachedDisk(
       autoDelete=disk_auto_delete,
       boot=True,
@@ -263,7 +274,8 @@ def CreateDefaultBootAttachedDiskMessage(
           diskSizeGb=disk_size_gb,
           diskType=disk_type),
       mode=messages.AttachedDisk.ModeValueValuesEnum.READ_WRITE,
-      type=messages.AttachedDisk.TypeValueValuesEnum.PERSISTENT)
+      type=messages.AttachedDisk.TypeValueValuesEnum.PERSISTENT,
+      diskEncryptionKey=disk_key)
 
 
 def CreateAcceleratorConfigMessages(messages, accelerator):
