@@ -13,8 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """Api client adapter containers commands."""
+
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 from os import linesep
 import time
 
@@ -22,6 +25,7 @@ from apitools.base.py import exceptions as apitools_exceptions
 from apitools.base.py import http_wrapper
 
 from googlecloudsdk.api_lib.compute import constants
+from googlecloudsdk.api_lib.container import constants as gke_constants
 from googlecloudsdk.api_lib.container import util
 from googlecloudsdk.api_lib.util import apis as core_apis
 from googlecloudsdk.calliope import exceptions
@@ -125,10 +129,12 @@ MAX_AUTHORIZED_NETWORKS_CIDRS = 20
 INGRESS = 'HttpLoadBalancing'
 HPA = 'HorizontalPodAutoscaling'
 DASHBOARD = 'KubernetesDashboard'
+SERVERLESS = 'Serverless'
 ISTIO = 'Istio'
 NETWORK_POLICY = 'NetworkPolicy'
 DEFAULT_ADDONS = [INGRESS, HPA]
-ADDONS_OPTIONS = [INGRESS, HPA, DASHBOARD, ISTIO, NETWORK_POLICY]
+ADDONS_OPTIONS = DEFAULT_ADDONS + [DASHBOARD, ISTIO, NETWORK_POLICY]
+ALPHA_ADDONS_OPTIONS = ADDONS_OPTIONS + [SERVERLESS]
 
 UNSPECIFIED = 'UNSPECIFIED'
 SECURE = 'SECURE'
@@ -350,7 +356,10 @@ class CreateClusterOptions(object):
                tpu_ipv4_cidr=None,
                enable_tpu=None,
                default_max_pods_per_node=None,
-               enable_managed_pod_identity=None):
+               enable_managed_pod_identity=None,
+               resource_usage_bigquery_dataset=None,
+               security_group=None,
+               enable_vertical_pod_autoscaling=None):
     self.node_machine_type = node_machine_type
     self.node_source_image = node_source_image
     self.node_disk_size_gb = node_disk_size_gb
@@ -414,6 +423,9 @@ class CreateClusterOptions(object):
     self.issue_client_certificate = issue_client_certificate
     self.default_max_pods_per_node = default_max_pods_per_node
     self.enable_managed_pod_identity = enable_managed_pod_identity
+    self.resource_usage_bigquery_dataset = resource_usage_bigquery_dataset
+    self.security_group = security_group
+    self.enable_vertical_pod_autoscaling = enable_vertical_pod_autoscaling
 
 
 class UpdateClusterOptions(object):
@@ -425,7 +437,6 @@ class UpdateClusterOptions(object):
                node_pool=None,
                monitoring_service=None,
                disable_addons=None,
-               istio_config=None,
                enable_autoscaling=None,
                min_nodes=None,
                max_nodes=None,
@@ -438,14 +449,14 @@ class UpdateClusterOptions(object):
                enable_autoprovisioning=None,
                enable_pod_security_policy=None,
                enable_binauthz=None,
-               concurrent_node_count=None):
+               concurrent_node_count=None,
+               enable_vertical_pod_autoscaling=None):
     self.version = version
     self.update_master = bool(update_master)
     self.update_nodes = bool(update_nodes)
     self.node_pool = node_pool
     self.monitoring_service = monitoring_service
     self.disable_addons = disable_addons
-    self.istio_config = istio_config
     self.enable_autoscaling = enable_autoscaling
     self.min_nodes = min_nodes
     self.max_nodes = max_nodes
@@ -459,6 +470,7 @@ class UpdateClusterOptions(object):
     self.enable_pod_security_policy = enable_pod_security_policy
     self.enable_binauthz = enable_binauthz
     self.concurrent_node_count = concurrent_node_count
+    self.enable_vertical_pod_autoscaling = enable_vertical_pod_autoscaling
 
 
 class SetMasterAuthOptions(object):
@@ -711,14 +723,14 @@ class APIAdapter(object):
     with progress_tracker.ProgressTracker(message, autotick=True,
                                           detail_message_callback=
                                           lambda: detail_message):
-      start_time = time.clock()
-      while timeout_s > (time.clock() - start_time):
+      start_time = time.time()
+      while timeout_s > (time.time() - start_time):
         try:
           operation = self.GetOperation(operation_ref)
           if self.IsOperationFinished(operation):
             # Success!
             log.info('Operation %s succeeded after %.3f seconds',
-                     operation, (time.clock() - start_time))
+                     operation, (time.time() - start_time))
             break
           detail_message = operation.detail
         except apitools_exceptions.HttpError as error:
@@ -743,87 +755,8 @@ class APIAdapter(object):
 
   def CreateClusterCommon(self, cluster_ref, options):
     """Returns a CreateCluster operation."""
-    node_config = self.messages.NodeConfig()
-    if options.node_machine_type:
-      node_config.machineType = options.node_machine_type
-    if options.node_disk_size_gb:
-      node_config.diskSizeGb = options.node_disk_size_gb
-    if options.disk_type:
-      node_config.diskType = options.disk_type
-    if options.node_source_image:
-      raise util.Error('cannot specify node source image in container v1 api')
-
-    NodeIdentityOptionsToNodeConfig(options, node_config)
-
-    if options.local_ssd_count:
-      node_config.localSsdCount = options.local_ssd_count
-
-    if options.tags:
-      node_config.tags = options.tags
-    else:
-      node_config.tags = []
-
-    if options.image_type:
-      node_config.imageType = options.image_type
-
-    custom_config = self.messages.CustomImageConfig()
-    if options.image:
-      custom_config.image = options.image
-    if options.image_project:
-      custom_config.imageProject = options.image_project
-    if options.image_family:
-      custom_config.imageFamily = options.image_family
-    if options.image or options.image_project or options.image_family:
-      node_config.nodeImageConfig = custom_config
-
-    _AddNodeLabelsToNodeConfig(node_config, options)
-    self._AddNodeTaintsToNodeConfig(node_config, options)
-
-    if options.preemptible:
-      node_config.preemptible = options.preemptible
-
-    if options.accelerators is not None:
-      type_name = options.accelerators['type']
-      # Accelerator count defaults to 1.
-      count = int(options.accelerators.get('count', 1))
-      node_config.accelerators = [
-          self.messages.AcceleratorConfig(acceleratorType=type_name,
-                                          acceleratorCount=count)
-      ]
-
-    if options.min_cpu_platform is not None:
-      node_config.minCpuPlatform = options.min_cpu_platform
-
-    _AddWorkloadMetadataToNodeConfig(node_config, options, self.messages)
-
-    max_nodes_per_pool = options.max_nodes_per_pool or MAX_NODES_PER_POOL
-    pools = (options.num_nodes + max_nodes_per_pool - 1) // max_nodes_per_pool
-    if pools == 1:
-      pool_names = ['default-pool']  # pool consistency with server default
-    else:
-      # default-pool-0, -1, ...
-      pool_names = ['default-pool-{0}'.format(i) for i in range(0, pools)]
-
-    pools = []
-    per_pool = (options.num_nodes + len(pool_names) - 1) // len(pool_names)
-    to_add = options.num_nodes
-    for name in pool_names:
-      nodes = per_pool if (to_add > per_pool) else to_add
-      autoscaling = None
-      if options.enable_autoscaling:
-        autoscaling = self.messages.NodePoolAutoscaling(
-            enabled=options.enable_autoscaling,
-            minNodeCount=options.min_nodes,
-            maxNodeCount=options.max_nodes)
-      pools.append(
-          self.messages.NodePool(
-              name=name,
-              initialNodeCount=nodes,
-              config=node_config,
-              autoscaling=autoscaling,
-              version=options.node_version,
-              management=self._GetNodeManagement(options)))
-      to_add -= nodes
+    node_config = self.ParseNodeConfig(options)
+    pools = self.ParseNodePools(options, node_config)
 
     cluster = self.messages.Cluster(
         name=cluster_ref.clusterId,
@@ -854,18 +787,8 @@ class APIAdapter(object):
           disable_network_policy=(
               NETWORK_POLICY not in options.addons))
       cluster.addonsConfig = addons
-    if options.enable_master_authorized_networks:
-      authorized_networks = self.messages.MasterAuthorizedNetworksConfig(
-          enabled=options.enable_master_authorized_networks)
-      if options.master_authorized_networks:
-        for network in options.master_authorized_networks:
-          authorized_networks.cidrBlocks.append(self.messages.CidrBlock(
-              cidrBlock=network))
-      cluster.masterAuthorizedNetworksConfig = authorized_networks
-    elif options.master_authorized_networks:
-      # Raise error if use --master-authorized-networks without
-      # --enable-master-authorized-networks.
-      raise util.Error(MISMATCH_AUTHORIZED_NETWORKS_ERROR_MSG)
+
+    self.ParseMasterAuthorizedNetworkOptions(options, cluster)
 
     if options.enable_kubernetes_alpha:
       cluster.enableKubernetesAlpha = options.enable_kubernetes_alpha
@@ -897,13 +820,7 @@ class APIAdapter(object):
                   startTime=options.maintenance_window)))
       cluster.maintenancePolicy = policy
 
-    if options.labels is not None:
-      labels = self.messages.Cluster.ResourceLabelsValue()
-      props = []
-      for k, v in sorted(six.iteritems(options.labels)):
-        props.append(labels.AdditionalProperty(key=k, value=v))
-      labels.additionalProperties = props
-      cluster.resourceLabels = labels
+    self.ParseResourceLabels(options, cluster)
 
     if options.enable_pod_security_policy is not None:
       cluster.podSecurityPolicyConfig = self.messages.PodSecurityPolicyConfig(
@@ -914,12 +831,136 @@ class APIAdapter(object):
           self.messages.ClientCertificateConfig(
               issueClientCertificate=options.issue_client_certificate))
 
+    if options.security_group is not None:
+      # The presence of the --security_group="foo" flag implies enabled=True.
+      cluster.authenticatorGroupsConfig = (
+          self.messages.AuthenticatorGroupsConfig(
+              enabled=True,
+              securityGroup=options.security_group))
+
     self.ParseIPAliasOptions(options, cluster)
     self.ParseAllowRouteOverlapOptions(options, cluster)
     self.ParsePrivateClusterOptions(options, cluster)
     self.ParseTpuOptions(options, cluster)
+    if options.enable_vertical_pod_autoscaling is not None:
+      cluster.verticalPodAutoscaling = self.messages.VerticalPodAutoscaling(
+          enabled=options.enable_vertical_pod_autoscaling)
     return cluster
 
+  def ParseNodeConfig(self, options):
+    """Creates node config based on node config options."""
+    node_config = self.messages.NodeConfig()
+    if options.node_machine_type:
+      node_config.machineType = options.node_machine_type
+    if options.node_disk_size_gb:
+      node_config.diskSizeGb = options.node_disk_size_gb
+    if options.disk_type:
+      node_config.diskType = options.disk_type
+    if options.node_source_image:
+      raise util.Error('cannot specify node source image in container v1 api')
+
+    NodeIdentityOptionsToNodeConfig(options, node_config)
+
+    if options.local_ssd_count:
+      node_config.localSsdCount = options.local_ssd_count
+
+    if options.tags:
+      node_config.tags = options.tags
+    else:
+      node_config.tags = []
+
+    if options.image_type:
+      node_config.imageType = options.image_type
+
+    self.ParseCustomNodeConfig(options, node_config)
+
+    _AddNodeLabelsToNodeConfig(node_config, options)
+    self._AddNodeTaintsToNodeConfig(node_config, options)
+
+    if options.preemptible:
+      node_config.preemptible = options.preemptible
+
+    self.ParseAcceleratorOptions(options, node_config)
+
+    if options.min_cpu_platform is not None:
+      node_config.minCpuPlatform = options.min_cpu_platform
+
+    _AddWorkloadMetadataToNodeConfig(node_config, options, self.messages)
+
+    return node_config
+
+  def ParseCustomNodeConfig(self, options, node_config):
+    """Parses custom node config options."""
+    custom_config = self.messages.CustomImageConfig()
+    if options.image:
+      custom_config.image = options.image
+    if options.image_project:
+      custom_config.imageProject = options.image_project
+    if options.image_family:
+      custom_config.imageFamily = options.image_family
+    if options.image or options.image_project or options.image_family:
+      node_config.nodeImageConfig = custom_config
+
+  def ParseNodePools(self, options, node_config):
+    """Creates a list of node pools for the cluster by parsing options.
+
+    Args:
+      options: cluster creation options
+      node_config: node configuration for nodes in the node pools
+    Returns:
+      List of node pools.
+    """
+    max_nodes_per_pool = options.max_nodes_per_pool or MAX_NODES_PER_POOL
+    pools = (options.num_nodes + max_nodes_per_pool - 1) // max_nodes_per_pool
+    if pools == 1:
+      pool_names = ['default-pool']  # pool consistency with server default
+    else:
+      # default-pool-0, -1, ...
+      pool_names = ['default-pool-{0}'.format(i) for i in range(0, pools)]
+
+    pools = []
+    per_pool = (options.num_nodes + len(pool_names) - 1) // len(pool_names)
+    to_add = options.num_nodes
+    for name in pool_names:
+      nodes = per_pool if (to_add > per_pool) else to_add
+      autoscaling = None
+      if options.enable_autoscaling:
+        autoscaling = self.messages.NodePoolAutoscaling(
+            enabled=options.enable_autoscaling,
+            minNodeCount=options.min_nodes,
+            maxNodeCount=options.max_nodes)
+      pools.append(
+          self.messages.NodePool(
+              name=name,
+              initialNodeCount=nodes,
+              config=node_config,
+              autoscaling=autoscaling,
+              version=options.node_version,
+              management=self._GetNodeManagement(options)))
+      to_add -= nodes
+    return pools
+
+  def ParseAcceleratorOptions(self, options, node_config):
+    """Parses accrelerator options for the nodes in the cluster."""
+    if options.accelerators is not None:
+      type_name = options.accelerators['type']
+      # Accelerator count defaults to 1.
+      count = int(options.accelerators.get('count', 1))
+      node_config.accelerators = [
+          self.messages.AcceleratorConfig(acceleratorType=type_name,
+                                          acceleratorCount=count)
+      ]
+
+  def ParseResourceLabels(self, options, cluster):
+    """Parses resource labels options for the cluster."""
+    if options.labels is not None:
+      labels = self.messages.Cluster.ResourceLabelsValue()
+      props = []
+      for k, v in sorted(six.iteritems(options.labels)):
+        props.append(labels.AdditionalProperty(key=k, value=v))
+      labels.additionalProperties = props
+      cluster.resourceLabels = labels
+
   def ParseIPAliasOptions(self, options, cluster):
     """Parses the options for IP Alias."""
     ip_alias_only_options = [('services-ipv4-cidr', options.services_ipv4_cidr),
@@ -1006,6 +1047,21 @@ class APIAdapter(object):
     if options.enable_tpu:
       cluster.enableTpu = options.enable_tpu
 
+  def ParseMasterAuthorizedNetworkOptions(self, options, cluster):
+    """Parses the options for master authorized networks."""
+    if options.enable_master_authorized_networks:
+      authorized_networks = self.messages.MasterAuthorizedNetworksConfig(
+          enabled=options.enable_master_authorized_networks)
+      if options.master_authorized_networks:
+        for network in options.master_authorized_networks:
+          authorized_networks.cidrBlocks.append(self.messages.CidrBlock(
+              cidrBlock=network))
+      cluster.masterAuthorizedNetworksConfig = authorized_networks
+    elif options.master_authorized_networks:
+      # Raise error if use --master-authorized-networks without
+      # --enable-master-authorized-networks.
+      raise util.Error(MISMATCH_AUTHORIZED_NETWORKS_ERROR_MSG)
+
   def CreateCluster(self, cluster_ref, options):
     cluster = self.CreateClusterCommon(cluster_ref, options)
     req = self.messages.CreateClusterRequest(
@@ -1077,6 +1133,22 @@ class APIAdapter(object):
           enabled=options.enable_binauthz)
       update = self.messages.ClusterUpdate(
           desiredBinaryAuthorization=binary_authorization)
+    elif options.enable_vertical_pod_autoscaling is not None:
+      vertical_pod_autoscaling = self.messages.VerticalPodAutoscaling(
+          enabled=options.enable_vertical_pod_autoscaling)
+      update = self.messages.ClusterUpdate(
+          desiredVerticalPodAutoscaling=vertical_pod_autoscaling)
+    elif options.resource_usage_bigquery_dataset is not None:
+      bigquery_destination = self.messages.BigQueryDestination(
+          datasetId=options.resource_usage_bigquery_dataset)
+      export_config = self.messages.ResourceUsageExportConfig(
+          bigqueryDestination=bigquery_destination)
+      update = self.messages.ClusterUpdate(
+          desiredResourceUsageExportConfig=export_config)
+    elif options.clear_resource_usage_bigquery_dataset is not None:
+      export_config = self.messages.ResourceUsageExportConfig()
+      update = self.messages.ClusterUpdate(
+          desiredResourceUsageExportConfig=export_config)
 
     if (options.master_authorized_networks
         and not options.enable_master_authorized_networks):
@@ -1495,6 +1567,9 @@ class APIAdapter(object):
     return (cluster.status ==
             self.messages.Cluster.StatusValueValuesEnum.DEGRADED)
 
+  def GetDegradedWarning(self, cluster):  # pylint: disable=unused-argument
+    return gke_constants.DEFAULT_DEGRADED_WARNING
+
   def GetOperationError(self, operation):
     return operation.statusMessage
 
@@ -1648,6 +1723,8 @@ class V1Beta1Adapter(V1Adapter):
 
   def CreateCluster(self, cluster_ref, options):
     cluster = self.CreateClusterCommon(cluster_ref, options)
+    if options.enable_autoprovisioning is not None:
+      cluster.autoscaling = self.CreateClusterAutoscalingCommon(options)
     if options.enable_stackdriver_kubernetes:
       if options.enable_cloud_logging and options.enable_cloud_monitoring:
         cluster.loggingService = 'logging.googleapis.com/kubernetes'
@@ -1741,6 +1818,16 @@ class V1Alpha1Adapter(V1Beta1Adapter):
       else:
         raise util.Error(CLOUD_LOGGING_OR_MONITORING_DISABLED_ERROR_MSG)
     if options.addons:
+      # Serverless is disabled by default.
+      if SERVERLESS in options.addons:
+        if ISTIO not in options.addons:
+          # Istio is a dependency of Serverless. We auto-enable Istio in no
+          # auth mode if not specified by the user.
+          log.warning('Auto-enabling the Istio addon, which is required to run '
+                      'the Serverless addon.')
+          options.addons.append(ISTIO)
+        cluster.addonsConfig.serverlessConfig = self.messages.ServerlessConfig(
+            disabled=False)
       # Istio is disabled by default
       if ISTIO in options.addons:
         istio_auth = self.messages.IstioConfig.AuthValueValuesEnum.AUTH_NONE
@@ -1756,6 +1843,12 @@ class V1Alpha1Adapter(V1Beta1Adapter):
     if options.enable_managed_pod_identity:
       cluster.managedPodIdentityConfig = self.messages.ManagedPodIdentityConfig(
           enabled=options.enable_managed_pod_identity)
+    if options.resource_usage_bigquery_dataset:
+      bigquery_destination = self.messages.BigQueryDestination(
+          datasetId=options.resource_usage_bigquery_dataset)
+      cluster.resourceUsageExportConfig = \
+          self.messages.ResourceUsageExportConfig(
+              bigqueryDestination=bigquery_destination)
 
     req = self.messages.CreateClusterRequest(
         parent=ProjectLocation(cluster_ref.projectId, cluster_ref.zone),
@@ -1765,18 +1858,22 @@ class V1Alpha1Adapter(V1Beta1Adapter):
 
   def UpdateCluster(self, cluster_ref, options):
     update = self.UpdateClusterCommon(options)
-    if (options.disable_addons is not None and
-        options.disable_addons.get(ISTIO) is not None):
-      istio_auth = self.messages.IstioConfig.AuthValueValuesEnum.AUTH_NONE
-      mtls = self.messages.IstioConfig.AuthValueValuesEnum.AUTH_MUTUAL_TLS
-      istio_config = options.istio_config
-      if istio_config is not None:
-        auth_config = istio_config.get('auth')
-        if auth_config is not None:
-          if auth_config == 'MUTUAL_TLS':
-            istio_auth = mtls
-      update.desiredAddonsConfig.istioConfig = self.messages.IstioConfig(
-          disabled=options.disable_addons.get(ISTIO), auth=istio_auth)
+    if options.disable_addons is not None:
+      if options.disable_addons.get(ISTIO) is not None:
+        istio_auth = self.messages.IstioConfig.AuthValueValuesEnum.AUTH_NONE
+        mtls = self.messages.IstioConfig.AuthValueValuesEnum.AUTH_MUTUAL_TLS
+        istio_config = options.istio_config
+        if istio_config is not None:
+          auth_config = istio_config.get('auth')
+          if auth_config is not None:
+            if auth_config == 'MUTUAL_TLS':
+              istio_auth = mtls
+        update.desiredAddonsConfig.istioConfig = self.messages.IstioConfig(
+            disabled=options.disable_addons.get(ISTIO), auth=istio_auth)
+      if options.disable_addons.get(SERVERLESS) is not None:
+        update.desiredAddonsConfig.serverlessConfig = (
+            self.messages.ServerlessConfig(
+                disabled=options.disable_addons.get(SERVERLESS)))
     if options.update_nodes and options.concurrent_node_count:
       update.concurrentNodeCount = options.concurrent_node_count
     op = self.client.projects_locations_clusters.Update(
@@ -1816,6 +1913,14 @@ class V1Alpha1Adapter(V1Beta1Adapter):
                                             cluster_ref.zone,
                                             cluster_ref.clusterId)))
 
+  def GetDegradedWarning(self, cluster):
+    if cluster.conditions:
+      codes = [condition.code for condition in cluster.conditions]
+      messages = [condition.message for condition in cluster.conditions]
+      return ('Codes: {0}\n' 'Messages: {1}.').format(codes, messages)
+    else:
+      return gke_constants.DEFAULT_DEGRADED_WARNING
+
   def ListUsableSubnets(self, project_ref, network_project, filter_arg):
     """List usable subnets for a given project.
 
