@@ -15,12 +15,16 @@
 """Reducer functions to generate instance props from prior state and flags."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 import argparse
+from googlecloudsdk.api_lib.sql import api_util as common_api_util
 from googlecloudsdk.api_lib.sql import constants
 from googlecloudsdk.api_lib.sql import instances as api_util
 from googlecloudsdk.calliope import arg_parsers
 from googlecloudsdk.calliope import exceptions
+from googlecloudsdk.core import properties
 from googlecloudsdk.core.util import files
 
 
@@ -219,7 +223,7 @@ def MachineType(instance=None, tier=None, memory=None, cpu=None):
     custom_type_string = _CustomMachineTypeString(
         cpu,
         # Converting from B to MiB.
-        int(memory / (2**20)))
+        memory // (2**20))
 
     # Updating the machine type that is set for the URIs.
     machine_type = custom_type_string
@@ -246,6 +250,25 @@ def OnPremisesConfiguration(sql_messages, source_ip_address, source_port):
       hostPort='{0}:{1}'.format(source_ip_address, source_port))
 
 
+def PrivateNetworkUrl(network):
+  """Generates the self-link of the instance's private network.
+
+  Args:
+    network: The ID of the network.
+
+  Returns:
+    string, the URL of the network.
+  """
+  client = common_api_util.SqlClient(common_api_util.API_VERSION_DEFAULT)
+  network_ref = client.resource_parser.Parse(
+      network,
+      params={
+          'project': properties.VALUES.core.project.GetOrFail,
+      },
+      collection='compute.networks')
+  return network_ref.SelfLink()
+
+
 def ReplicaConfiguration(sql_messages,
                          master_username,
                          master_password,
