@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*- #
 # Copyright 2017 Google Inc. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -18,9 +19,11 @@ from __future__ import absolute_import
 from __future__ import division
 
 from __future__ import unicode_literals
+from googlecloudsdk.calliope import arg_parsers
 from googlecloudsdk.calliope import exceptions
 from googlecloudsdk.command_lib.compute import completers as compute_completers
 from googlecloudsdk.command_lib.compute import flags as compute_flags
+from googlecloudsdk.command_lib.util.apis import arg_utils
 
 VALID_PLANS = ['12-month', '36-month']
 _REQUIRED_RESOURCES = sorted(['VCPU', 'MEMORY'])
@@ -76,3 +79,40 @@ def MakeCommitmentArg(plural):
       name='commitment',
       regional_collection='compute.regionCommitments',
       region_explanation=compute_flags.REGION_PROPERTY_EXPLANATION)
+
+
+def AddCreateFlags(parser):
+  """Add general arguments for `commitments create` flag."""
+  parser.add_argument('--plan',
+                      required=True,
+                      choices=VALID_PLANS,
+                      help=('Duration of the commitment.'))
+  resources_help = """\
+  Resources to be included in the commitment commitment:
+  * MEMORY should include unit (eg. 3072MB or 9GB). If no units are specified,
+    GB is assumed.
+  * VCPU is number of committed cores.
+  Ratio between number of VCPU cores and memory must conform to limits
+  described on:
+  https://cloud.google.com/compute/docs/instances/creating-instance-with-custom-machine-type"""
+  parser.add_argument('--resources',
+                      required=True,
+                      help=resources_help,
+                      metavar='RESOURCE=COMMITMENT',
+                      type=arg_parsers.ArgDict(spec={
+                          'VCPU': int,
+                          'MEMORY': arg_parsers.BinarySize(),
+                      }))
+
+
+def GetTypeMapperFlag(messages):
+  """Helper to get a choice flag from the commitment type enum."""
+  return arg_utils.ChoiceEnumMapper(
+      '--type',
+      messages.Commitment.TypeValueValuesEnum,
+      help_str=(
+          'Type of commitment. `memory-optimized` indicates that the '
+          'commitment is for memory-optimized VMs.'),
+      default='general-purpose',
+      include_filter=lambda x: x != 'TYPE_UNSPECIFIED')
+
