@@ -16,9 +16,9 @@
 """Helpers for flags in commands working with Google Cloud Functions."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
 
-from googlecloudsdk.api_lib.functions import triggers
 from googlecloudsdk.api_lib.functions import util as api_util
 from googlecloudsdk.calliope import actions
 from googlecloudsdk.calliope import arg_parsers
@@ -175,17 +175,20 @@ def AddRuntimeFlag(parser):
   parser.add_argument(
       '--runtime',
       help="""\
-          'The runtime in which to run the function. Defaults to Node.js 6.
+          The runtime in which to run the function. Defaults to Node.js 6.
 
           Choices:
 
           - `nodejs6`: Node.js 6
           - `nodejs8`: Node.js 8
           - `python37`: Python 3.7
-          - `go`: Golang
-          - `java`: Java
-          - `csharp`: C#
-          """,
+          """)
+
+
+def AddConnectedVPCFlag(parser):
+  parser.add_argument(
+      '--connected-vpc',
+      help='Specifies the VPC network to connect the function to.',
       hidden=True)
 
 
@@ -204,6 +207,33 @@ def AddEntryPointFlag(parser):
   )
 
 
+def AddMaxInstancesFlag(parser):
+  """Add flag for specifying the max instances for a function."""
+  mutex_group = parser.add_group(mutex=True)
+  mutex_group.add_argument(
+      '--max-instances',
+      type=arg_parsers.BoundedInt(lower_bound=1),
+      hidden=True,
+      help="""\
+      Sets the maximum number of instances for the function. There may be
+      per-region and/or per-function upper limits for max-instances. The
+      deploy fails if the upper limit is exceeded.
+
+      A function execution that would exceed max-instances times out.
+      """
+  )
+  mutex_group.add_argument(
+      '--clear-max-instances',
+      action='store_true',
+      hidden=True,
+      help="""\
+      Sets the maximum number of instances for the function to the Cloud
+      Functions default value. The default value is determined by the Cloud
+      Platform.
+      """
+  )
+
+
 def AddTriggerFlagGroup(parser):
   """Add arguments specyfying functions trigger to the parser."""
   # You can also use --trigger-provider but it is hidden argument so not
@@ -239,7 +269,6 @@ def AddTriggerFlagGroup(parser):
   trigger_provider_spec_group.add_argument(
       '--trigger-event',
       metavar='EVENT_TYPE',
-      choices=sorted(triggers.INPUT_TRIGGER_PROVIDER_REGISTRY.AllEventLabels()),
       help=('Specifies which action should trigger the function. For a '
             'list of acceptable values, call `functions event-types list`.')
   )
