@@ -13,8 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """ml-engine jobs command code."""
+
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 from apitools.base.py import exceptions
 
 from googlecloudsdk.api_lib.ml_engine import jobs
@@ -73,18 +76,18 @@ _ACCELERATOR_MAP = arg_utils.ChoiceEnumMapper(
     required=True)
 
 _SCALE_TIER_CHOICES = {
-    'BASIC': ('basic', ('A single worker instance. This tier is suitable for '
+    'BASIC': ('basic', ('Single worker instance. This tier is suitable for '
                         'learning how to use Cloud ML Engine, and for '
                         'experimenting with new models using small datasets.')),
     'STANDARD_1': ('standard-1', 'Many workers and a few parameter servers.'),
     'PREMIUM_1': ('premium-1',
-                  'A large number of workers with many parameter servers.'),
-    'BASIC_GPU': ('basic-gpu', 'A single worker instance with a GPU.'),
-    'BASIC_TPU': ('basic-tpu', 'A single worker instance with a Cloud TPU.'),
+                  'Large number of workers with many parameter servers.'),
+    'BASIC_GPU': ('basic-gpu', 'Single worker instance with a GPU.'),
+    'BASIC_TPU': ('basic-tpu', 'Single worker instance with a Cloud TPU.'),
     'CUSTOM': ('custom', """\
-The CUSTOM tier is not a set tier, but rather enables you to use your own
+CUSTOM tier is not a set tier, but rather enables you to use your own
 cluster specification. When you use this tier, set values to configure your
-processing cluster according to these guidelines (using the --config flag):
+processing cluster according to these guidelines (using the `--config` flag):
 
 * You _must_ set `TrainingInput.masterType` to specify the type of machine to
   use for your master node. This is the only required setting.
@@ -107,7 +110,7 @@ _TRAINING_SCALE_TIER_MAPPER = arg_utils.ChoiceEnumMapper(
     jobs.GetMessagesModule()
     .GoogleCloudMlV1TrainingInput.ScaleTierValueValuesEnum,
     custom_mappings=_SCALE_TIER_CHOICES,
-    help_str=('Specifies the machine types, the number of replicas for workers '
+    help_str=('Specify the machine types, the number of replicas for workers, '
               'and parameter servers.'),
     default=None)
 
@@ -308,8 +311,8 @@ def SubmitPrediction(jobs_client, job,
                      model_dir=None, model=None, version=None,
                      input_paths=None, data_format=None, output_path=None,
                      region=None, runtime_version=None, max_worker_count=None,
-                     batch_size=None, labels=None, accelerator_count=None,
-                     accelerator_type=None):
+                     batch_size=None, signature_name=None, labels=None,
+                     accelerator_count=None, accelerator_type=None):
   """Submit a prediction job."""
   _ValidateSubmitPredictionArgs(model_dir, version)
 
@@ -328,6 +331,7 @@ def SubmitPrediction(jobs_client, job,
       runtime_version=runtime_version,
       max_worker_count=max_worker_count,
       batch_size=batch_size,
+      signature_name=signature_name,
       labels=labels,
       accelerator_count=accelerator_count,
       accelerator_type=_ACCELERATOR_MAP.GetEnumForChoice(accelerator_type)
