@@ -18,6 +18,7 @@
 from __future__ import absolute_import
 from __future__ import division
 from __future__ import unicode_literals
+
 import functools
 import os
 import re
@@ -250,6 +251,7 @@ class _Sections(object):
     self.container = _SectionContainer()
     self.core = _SectionCore()
     self.dataproc = _SectionDataproc()
+    self.deployment_manager = _SectionDeploymentManager()
     self.devshell = _SectionDevshell()
     self.emulator = _SectionEmulator()
     self.experimental = _SectionExperimental()
@@ -279,6 +281,7 @@ class _Sections(object):
         self.container,
         self.core,
         self.dataproc,
+        self.deployment_manager,
         self.devshell,
         self.emulator,
         self.experimental,
@@ -786,26 +789,6 @@ class _SectionContainer(_Section):
         default=False,
         help_text='If True, use application default credentials to authenticate'
         ' to the cluster API server.')
-    self.use_v1_api = self._AddBool(
-        'use_v1_api',
-        default=False,
-        help_text='This property is DEPRECATED. '
-        'If True, all `gcloud` Kubernetes Engine commands (regardless '
-        'of release track) will use the v1 API; otherwise, `gcloud beta` track '
-        'commands will use v1beta1 API and `gcloud alpha` track commands will '
-        'use v1alpha1 API. By default, this property is set to false. The '
-        'Kubernetes Engine v1alpha1 API is whitelist-only at this time. '
-        'Note: use_v1_api is an alias of use_v1_api_client.')
-    self.use_v1_api_client = self._AddBool(
-        'use_v1_api_client',
-        default=False,
-        help_text='This property is DEPRECATED. '
-        'If True, all `gcloud` Kubernetes Engine commands (regardless '
-        'of release track) will use the v1 API; otherwise, `gcloud beta` track '
-        'commands will use v1beta1 API and `gcloud alpha` track commands will '
-        'use v1alpha1 API. By default, this property is set to false. The '
-        'Kubernetes Engine v1alpha1 API is whitelist-only at this time. '
-        'Note: use_v1_api_client is an alias of use_v1_api.')
     self.new_scopes_behavior = self._AddBool(
         'new_scopes_behavior',
         default=False,
@@ -1314,6 +1297,19 @@ class _SectionDataproc(_Section):
             'from other Cloud Dataproc regions.'))
 
 
+class _SectionDeploymentManager(_Section):
+  """Contains the properties for the 'deployment_manager' section."""
+
+  def __init__(self):
+    super(_SectionDeploymentManager, self).__init__('deployment_manager')
+    self.glob_imports = self._AddBool(
+        'glob_imports',
+        default=False,
+        help_text=(
+            'Enable import path globbing. Uses glob patterns to match multiple '
+            'imports in a config file.'))
+
+
 class _SectionInteractive(_Section):
   """Contains the properties for the 'interactive' section."""
 
@@ -1451,12 +1447,15 @@ class _SectionApiEndpointOverrides(_Section):
     self.deploymentmanager = self._Add('deploymentmanager')
     self.discovery = self._Add('discovery')
     self.dns = self._Add('dns')
+    self.file = self._Add('file')
+    self.firestore = self._Add('firestore')
     self.genomics = self._Add('genomics')
     self.iam = self._Add('iam')
     self.language = self._Add('language')
     self.logging = self._Add('logging')
     self.manager = self._Add('manager')
     self.ml = self._Add('ml')
+    self.monitoring = self._Add('monitoring')
     self.oslogin = self._Add('oslogin')
     self.pubsub = self._Add('pubsub')
     self.replicapoolupdater = self._Add('replicapoolupdater')
@@ -1475,6 +1474,7 @@ class _SectionApiEndpointOverrides(_Section):
     self.toolresults = self._Add('toolresults')
     self.tpu = self._Add('tpu')
     self.vision = self._Add('vision')
+    self.vpcaccess = self._Add('vpcaccess')
 
   def EndpointValidator(self, value):
     """Checks to see if the endpoint override string is valid."""
@@ -1534,7 +1534,7 @@ class _SectionAccessContextManager(_Section):
                                                        hidden=True)
     self.policy = self._Add(
         'policy',
-        help_text=('The ID of the policy resource to operate on. Can be found '
+        help_text=('ID of the policy resource to operate on. Can be found '
                    'by running the `access-context-manager policies list` '
                    'command.'))
 
@@ -1546,7 +1546,7 @@ class _SectionRedis(_Section):
     super(_SectionRedis, self).__init__('redis')
     self.region = self._Add(
         'region',
-        help_text='The default region to use when working with Cloud '
+        help_text='Default region to use when working with Cloud '
         'Memorystore for Redis resources. When a `region` is required but not '
         'provided by a flag, the command will fall back to this value, if set.')
 
