@@ -15,11 +15,13 @@
 """The main command group for bigtable."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 from googlecloudsdk.calliope import base
 
 
-@base.ReleaseTracks(base.ReleaseTrack.BETA)
+@base.ReleaseTracks(base.ReleaseTrack.BETA, base.ReleaseTrack.ALPHA)
 class BigtableV2(base.Group):
   """Manage your Cloud Bigtable storage."""
 
