@@ -15,7 +15,9 @@
 """Command for creating firewall rules."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 from googlecloudsdk.api_lib.compute import base_classes
 from googlecloudsdk.api_lib.compute import firewalls_utils
 from googlecloudsdk.calliope import base
@@ -138,9 +140,11 @@ class BetaCreate(Create):
         with_service_account=True,
         with_disabled=cls.with_disabled)
     firewalls_utils.AddArgsForServiceAccount(parser, for_update=False)
+    flags.AddEnableLogging(parser, default=None)
 
   def _CreateFirewall(self, holder, args):
     firewall, project = super(BetaCreate, self)._CreateFirewall(holder, args)
+    firewall.enableLogging = args.enable_logging
     if args.disabled is not None:
       firewall.disabled = args.disabled
 
@@ -167,12 +171,6 @@ class AlphaCreate(BetaCreate):
     firewalls_utils.AddArgsForServiceAccount(parser, for_update=False)
     flags.AddEnableLogging(parser, default=None)
 
-  def _CreateFirewall(self, holder, args):
-    firewall, project = super(AlphaCreate, self)._CreateFirewall(holder, args)
-    firewall.enableLogging = args.enable_logging
-
-    return firewall, project
-
 
 Create.detailed_help = {
     'brief': 'Create a Google Compute Engine firewall rule.',
