@@ -14,7 +14,9 @@
 # limitations under the License.
 """Command for updating health checks."""
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 from googlecloudsdk.api_lib.compute import base_classes
 from googlecloudsdk.api_lib.compute import health_checks_utils
 from googlecloudsdk.calliope import base
@@ -42,7 +44,7 @@ class Update(base.UpdateCommand):
     health_checks_utils.AddHttpRelatedUpdateArgs(parser)
     health_checks_utils.AddProtocolAgnosticUpdateArgs(parser, 'HTTPS')
 
-  def GetGetRequest(self, client, health_check_ref):
+  def _GetGetRequest(self, client, health_check_ref):
     """Returns a request for fetching the existing health check."""
     return (client.apitools_client.healthChecks,
             'Get',
@@ -50,7 +52,7 @@ class Update(base.UpdateCommand):
                 healthCheck=health_check_ref.Name(),
                 project=health_check_ref.project))
 
-  def GetSetRequest(self, client, health_check_ref, replacement):
+  def _GetSetRequest(self, client, health_check_ref, replacement):
     """Returns a request for updating the health check."""
     return (client.apitools_client.healthChecks,
             'Update',
@@ -140,7 +142,7 @@ class Update(base.UpdateCommand):
     self.ValidateArgs(args)
     health_check_ref = self.HEALTH_CHECK_ARG.ResolveAsResource(
         args, holder.resources)
-    get_request = self.GetGetRequest(client, health_check_ref)
+    get_request = self._GetGetRequest(client, health_check_ref)
 
     objects = client.MakeRequests([get_request])
 
@@ -156,10 +158,10 @@ class Update(base.UpdateCommand):
       return objects
 
     return client.MakeRequests(
-        [self.GetSetRequest(client, health_check_ref, new_object)])
+        [self._GetSetRequest(client, health_check_ref, new_object)])
 
 
-@base.ReleaseTracks(base.ReleaseTrack.BETA, base.ReleaseTrack.ALPHA)
+@base.ReleaseTracks(base.ReleaseTrack.BETA)
 class UpdateBeta(Update):
   """Update a HTTPS health check.
 
@@ -201,3 +203,70 @@ class UpdateBeta(Update):
     if (args.description is None and args.host is None and args.response is None
         and args.port_name is None and args_unset):
       raise exceptions.ToolException('At least one property must be modified.')
+
+
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+class UpdateAlpha(UpdateBeta):
+  """Update a HTTPS health check.
+
+  *{command}* is used to update an existing HTTPS health check. Only
+  arguments passed in will be updated on the health check. Other
+  attributes will remain unaffected.
+  """
+
+  @classmethod
+  def Args(cls, parser):
+    cls.HEALTH_CHECK_ARG = flags.HealthCheckArgument(
+        'HTTPS', include_alpha=True)
+    cls.HEALTH_CHECK_ARG.AddArgument(parser, operation_type='update')
+    health_checks_utils.AddHttpRelatedUpdateArgs(parser)
+    health_checks_utils.AddProtocolAgnosticUpdateArgs(parser, 'HTTPS')
+    health_checks_utils.AddHttpRelatedResponseArg(parser)
+
+  def _GetRegionalGetRequest(self, client, health_check_ref):
+    """Returns a request for fetching the existing health check."""
+    return (client.apitools_client.regionHealthChecks, 'Get',
+            client.messages.ComputeRegionHealthChecksGetRequest(
+                healthCheck=health_check_ref.Name(),
+                project=health_check_ref.project,
+                region=health_check_ref.region))
+
+  def _GetRegionalSetRequest(self, client, health_check_ref, replacement):
+    """Returns a request for updating the health check."""
+    return (client.apitools_client.regionHealthChecks, 'Update',
+            client.messages.ComputeRegionHealthChecksUpdateRequest(
+                healthCheck=health_check_ref.Name(),
+                healthCheckResource=replacement,
+                project=health_check_ref.project,
+                region=health_check_ref.region))
+
+  def Run(self, args):
+    holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
+    client = holder.client
+
+    self.ValidateArgs(args)
+    health_check_ref = self.HEALTH_CHECK_ARG.ResolveAsResource(
+        args, holder.resources)
+    if health_checks_utils.IsRegionalHealthCheckRef(health_check_ref):
+      get_request = self._GetRegionalGetRequest(client, health_check_ref)
+    else:
+      get_request = self._GetGetRequest(client, health_check_ref)
+
+    objects = client.MakeRequests([get_request])
+
+    new_object = self.Modify(client, args, objects[0])
+
+    # If existing object is equal to the proposed object or if
+    # Modify() returns None, then there is no work to be done, so we
+    # print the resource and return.
+    if objects[0] == new_object:
+      log.status.Print('No change requested; skipping update for [{0}].'.format(
+          objects[0].name))
+      return objects
+
+    if health_checks_utils.IsRegionalHealthCheckRef(health_check_ref):
+      set_request = self._GetRegionalSetRequest(client, health_check_ref,
+                                                new_object)
+    else:
+      set_request = self._GetSetRequest(client, health_check_ref, new_object)
+    return client.MakeRequests([set_request])
