@@ -15,7 +15,9 @@
 """Export image command."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 from googlecloudsdk.api_lib.compute import base_classes
 from googlecloudsdk.api_lib.compute import daisy_utils
 from googlecloudsdk.api_lib.compute import image_utils
@@ -25,6 +27,7 @@ from googlecloudsdk.core import properties
 
 _DEFAULT_WORKFLOW = '../workflows/export/image_export.wf.json'
 _EXTERNAL_WORKFLOW = '../workflows/export/image_export_ext.wf.json'
+_OUTPUT_FILTER = ['[Daisy', '[image-export', '  image', 'ERROR']
 
 
 class Export(base.CreateCommand):
@@ -101,7 +104,7 @@ class Export(base.CreateCommand):
 
     tags = ['gce-daisy-image-export']
     return daisy_utils.RunDaisyBuild(args, workflow, variables,
-                                     tags=tags)
+                                     tags=tags, output_filter=_OUTPUT_FILTER)
 
 Export.detailed_help = {
     'brief': 'Export a Google Compute Engine image',
