@@ -13,8 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """Command for creating instances."""
+
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 import re
 
 from googlecloudsdk.api_lib.compute import base_classes
@@ -69,24 +72,22 @@ def _CommonArgs(parser,
                 # TODO(b/80138906): Release track should not be passed around.
                 release_track,
                 support_public_dns,
-                support_network_tier,
                 enable_regional=False,
                 support_local_ssd_size=False,
                 enable_kms=False,
-                support_sole_tenancy=False,
-                supports_resource_policies=False):
+                supports_resource_policies=False,
+                enable_snapshots=False):
   """Register parser args common to all tracks."""
   metadata_utils.AddMetadataArgs(parser)
   instances_flags.AddDiskArgs(parser, enable_regional, enable_kms=enable_kms)
-  instances_flags.AddCreateDiskArgs(parser, enable_kms=enable_kms)
+  instances_flags.AddCreateDiskArgs(parser, enable_kms=enable_kms,
+                                    enable_snapshots=enable_snapshots)
   if support_local_ssd_size:
     instances_flags.AddLocalSsdArgsWithSize(parser)
   else:
     instances_flags.AddLocalSsdArgs(parser)
   instances_flags.AddCanIpForwardArgs(parser)
-  instances_flags.AddAddressArgs(
-      parser, instances=True,
-      support_network_tier=support_network_tier)
+  instances_flags.AddAddressArgs(parser, instances=True)
   instances_flags.AddAcceleratorArgs(parser)
   instances_flags.AddMachineTypeArgs(parser)
   deprecate_maintenance_policy = release_track in [base.ReleaseTrack.ALPHA]
@@ -103,17 +104,17 @@ def _CommonArgs(parser,
   instances_flags.AddCustomMachineTypeArgs(parser)
   instances_flags.AddNetworkArgs(parser)
   instances_flags.AddPrivateNetworkIpArgs(parser)
-  instances_flags.AddImageArgs(parser)
+  instances_flags.AddImageArgs(parser, enable_snapshots=enable_snapshots)
   instances_flags.AddDeletionProtectionFlag(parser)
   instances_flags.AddPublicPtrArgs(parser, instance=True)
   if support_public_dns:
     instances_flags.AddPublicDnsArgs(parser, instance=True)
-  if support_network_tier:
-    instances_flags.AddNetworkTierArgs(parser, instance=True)
-  if support_sole_tenancy:
-    sole_tenancy_flags.AddNodeAffinityFlagToParser(parser)
+  instances_flags.AddNetworkTierArgs(parser, instance=True)
+
+  sole_tenancy_flags.AddNodeAffinityFlagToParser(parser)
+
   if supports_resource_policies:
-    maintenance_flags.AddResourcePoliciesArgs(parser, 'added to')
+    maintenance_flags.AddResourcePoliciesArgs(parser, 'added to', 'instance')
 
   labels_util.AddCreateLabelsFlags(parser)
   instances_flags.AddMinCpuPlatformArgs(parser, release_track)
@@ -138,9 +139,8 @@ class Create(base.CreateCommand):
   """Create Google Compute Engine virtual machine instances."""
 
   _support_kms = False
-  _support_network_tier = False
   _support_public_dns = False
-  _support_node_affinity = False
+  _support_snapshots = False
 
   @classmethod
   def Args(cls, parser):
@@ -148,8 +148,8 @@ class Create(base.CreateCommand):
         parser,
         release_track=base.ReleaseTrack.GA,
         support_public_dns=cls._support_public_dns,
-        support_network_tier=cls._support_network_tier,
         enable_kms=cls._support_kms,
+        enable_snapshots=cls._support_snapshots
     )
     cls.SOURCE_INSTANCE_TEMPLATE = (
         instances_flags.MakeSourceInstanceTemplateArg())
@@ -195,6 +195,7 @@ class Create(base.CreateCommand):
           'create_disk', 'boot_disk_kms_key', 'boot_disk_kms_project',
           'boot_disk_kms_location', 'boot_disk_kms_keyring',
       ])
+
     if (skip_defaults and
         not instance_utils.IsAnySpecified(args, *flags_to_check)):
       return [[] for _ in instance_refs]
@@ -219,7 +220,8 @@ class Create(base.CreateCommand):
               csek_keys,
               getattr(args, 'create_disk', []),
               instance_ref,
-              enable_kms=self._support_kms))
+              enable_kms=self._support_kms,
+              enable_snapshots=self._support_snapshots))
       local_ssds = []
       for x in args.local_ssd or []:
         local_ssds.append(
@@ -234,6 +236,14 @@ class Create(base.CreateCommand):
         )
 
       if create_boot_disk:
+        if self._support_snapshots:
+          boot_snapshot_uri = instance_utils.ResolveSnapshotURI(
+              user_project=instance_refs[0].project,
+              snapshot=args.source_snapshot,
+              resource_parser=resource_parser)
+        else:
+          boot_snapshot_uri = None
+
         boot_disk = instance_utils.CreateDefaultBootAttachedDiskMessage(
             compute_client, resource_parser,
             disk_type=args.boot_disk_type,
@@ -246,6 +256,7 @@ class Create(base.CreateCommand):
             instance_ref=instance_ref,
             csek_keys=csek_keys,
             kms_args=args,
+            snapshot_uri=boot_snapshot_uri,
             enable_kms=self._support_kms)
         persistent_disks = [boot_disk] + persistent_disks
       else:
@@ -296,17 +307,6 @@ class Create(base.CreateCommand):
         project_to_sa[instance_ref.project] = service_accounts
     return project_to_sa
 
-  def _GetGetSoleTenancyHost(self, args, resource_parser, instance_ref):
-    sole_tenancy_host_arg = getattr(args, 'sole_tenancy_host', None)
-    if sole_tenancy_host_arg:
-      sole_tenancy_host_ref = resource_parser.Parse(
-          sole_tenancy_host_arg, collection='compute.hosts',
-          params={
-              'project': instance_ref.project,
-              'zone': instance_ref.zone
-          })
-      return sole_tenancy_host_ref.SelfLink()
-
   def _GetImageUri(
       self, args, client, create_boot_disk, instance_refs, resource_parser):
     if create_boot_disk:
@@ -327,8 +327,7 @@ class Create(base.CreateCommand):
           resources=resource_parser,
           compute_client=compute_client,
           network_interface_arg=args.network_interface,
-          instance_refs=instance_refs,
-          support_network_tier=self._support_network_tier)
+          instance_refs=instance_refs)
     else:
       instances_flags.ValidatePublicPtrFlags(args)
       if self._support_public_dns is True:
@@ -349,8 +348,7 @@ class Create(base.CreateCommand):
     skip_defaults = source_instance_template is not None
 
     scheduling = instance_utils.GetScheduling(
-        args, compute_client, skip_defaults,
-        support_node_affinity=self._support_node_affinity)
+        args, compute_client, skip_defaults, support_node_affinity=True)
     tags = instance_utils.GetTags(args, compute_client)
     labels = instance_utils.GetLabels(args, compute_client)
     metadata = instance_utils.GetMetadata(args, compute_client, skip_defaults)
@@ -377,7 +375,6 @@ class Create(base.CreateCommand):
           messages=compute_client.messages, args=args)
 
     csek_keys = csek_utils.CsekKeyStore.FromArgs(args, allow_rsa_encrypted)
-
     disks_messages = self._GetDiskMessagess(
         args, skip_defaults, instance_refs, compute_client, resource_parser,
         create_boot_disk, boot_disk_size_gb, image_uri, csek_keys)
@@ -409,11 +406,6 @@ class Create(base.CreateCommand):
           scheduling=scheduling,
           tags=tags)
 
-      sole_tenancy_host = self._GetGetSoleTenancyHost(
-          args, resource_parser, instance_ref)
-      if sole_tenancy_host:
-        instance.host = sole_tenancy_host
-
       resource_policies = getattr(
           args, 'resource_policies', None)
       if resource_policies:
@@ -443,13 +435,13 @@ class Create(base.CreateCommand):
     return requests
 
   def Run(self, args):
-    instances_flags.ValidateDiskFlags(args, enable_kms=self._support_kms)
+    instances_flags.ValidateDiskFlags(args, enable_kms=self._support_kms,
+                                      enable_snapshots=self._support_snapshots)
     instances_flags.ValidateLocalSsdFlags(args)
     instances_flags.ValidateNicFlags(args)
     instances_flags.ValidateServiceAccountAndScopeArgs(args)
     instances_flags.ValidateAcceleratorArgs(args)
-    if self._support_network_tier:
-      instances_flags.ValidateNetworkTierArgs(args)
+    instances_flags.ValidateNetworkTierArgs(args)
 
     holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
     compute_client = holder.client
@@ -506,14 +498,13 @@ class CreateBeta(Create):
   """Create Google Compute Engine virtual machine instances."""
 
   _support_kms = True
-  _support_network_tier = True
   _support_public_dns = False
-  _support_node_affinity = True
+  _support_snapshots = False
 
   def _GetNetworkInterfaces(
       self, args, client, holder, instance_refs, skip_defaults):
-    return instance_utils.GetNetworkInterfacesBeta(args, client, holder,
-                                                   instance_refs, skip_defaults)
+    return instance_utils.GetNetworkInterfaces(args, client, holder,
+                                               instance_refs, skip_defaults)
 
   @classmethod
   def Args(cls, parser):
@@ -521,10 +512,9 @@ class CreateBeta(Create):
         parser,
         release_track=base.ReleaseTrack.BETA,
         support_public_dns=cls._support_public_dns,
-        support_network_tier=cls._support_network_tier,
         enable_regional=True,
         enable_kms=cls._support_kms,
-        support_sole_tenancy=True,
+        enable_snapshots=cls._support_snapshots,
     )
     cls.SOURCE_INSTANCE_TEMPLATE = (
         instances_flags.MakeSourceInstanceTemplateArg())
@@ -537,9 +527,8 @@ class CreateAlpha(CreateBeta):
   """Create Google Compute Engine virtual machine instances."""
 
   _support_kms = True
-  _support_network_tier = True
   _support_public_dns = True
-  _support_node_affinity = True
+  _support_snapshots = True
 
   def _GetNetworkInterfaces(
       self, args, client, holder, instance_refs, skip_defaults):
@@ -553,11 +542,10 @@ class CreateAlpha(CreateBeta):
         parser,
         release_track=base.ReleaseTrack.ALPHA,
         support_public_dns=cls._support_public_dns,
-        support_network_tier=cls._support_network_tier,
         enable_regional=True,
         support_local_ssd_size=True,
         enable_kms=cls._support_kms,
-        support_sole_tenancy=True,
+        enable_snapshots=cls._support_snapshots,
         supports_resource_policies=True)
     CreateAlpha.SOURCE_INSTANCE_TEMPLATE = (
         instances_flags.MakeSourceInstanceTemplateArg())
