@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*- #
 # Copyright 2017 Google Inc. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +15,6 @@
 """Commands for reading and manipulating security policies rules."""
 from __future__ import absolute_import
 from __future__ import division
-from __future__ import print_function
 
 from __future__ import unicode_literals
 from googlecloudsdk.calliope import base
