@@ -20,7 +20,5 @@ from __future__ import unicode_literals
 from googlecloudsdk.calliope import base
 
 
-@base.Hidden
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
 class Attestations(base.Group):
   """Create and manage Google Binary Authorization attestations."""
