@@ -14,8 +14,11 @@
 # limitations under the License.
 
 """Create cluster command."""
+
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 from apitools.base.py import exceptions as apitools_exceptions
 
 from googlecloudsdk.api_lib.container import api_adapter
@@ -158,20 +161,17 @@ for examples.
 def ValidateBasicAuthFlags(args):
   """Validates flags associated with basic auth.
 
-  Check that args don't conflict, but only if they're both specified; overwrites
-  username if enable_basic_auth is specified; and checks that password is set
-  only if username is non-empty.
+  Overwrites username if enable_basic_auth is specified; checks that password is
+  set if username is non-empty.
 
   Args:
     args: an argparse namespace. All the arguments that were provided to this
       command invocation.
 
   Raises:
-    util.Error, if flags conflict.
+    util.Error, if username is non-empty and password is not set.
   """
   if args.IsSpecified('enable_basic_auth'):
-    if args.IsSpecified('username'):
-      raise util.Error(constants.USERNAME_ENABLE_BASIC_AUTH_ERROR_MSG)
     if not args.enable_basic_auth:
       args.username = ''
     # Right now, enable_basic_auth is a no-op because username defaults to
@@ -181,12 +181,33 @@ def ValidateBasicAuthFlags(args):
 
 
 def ParseCreateOptionsBase(args):
+  """Parses the flags provided with the cluster creation command."""
+  if not (args.IsSpecified('enable_basic_auth') or
+          args.IsSpecified('username')):
+    log.warning('Starting in 1.12, new clusters will have basic '
+                'authentication disabled by default. Basic authentication '
+                'can be enabled (or disabled) manually using the '
+                '`--[no-]enable-basic-auth` flag.')
+  if not args.IsSpecified('issue_client_certificate'):
+    log.warning('Starting in 1.12, new clusters will not have a client '
+                'certificate issued. You can manually enable (or disable) the '
+                'issuance of the client certificate using the '
+                '`--[no-]issue-client-certificate` flag.')
+
   flags.MungeBasicAuthFlags(args)
   if (args.IsSpecified('enable_cloud_endpoints') and
       properties.VALUES.container.new_scopes_behavior.GetBool()):
     raise util.Error('Flag --[no-]enable-cloud-endpoints is not allowed if '
                      'property container/ new_scopes_behavior is set to true.')
-  flags.WarnForUnspecifiedAutorepair(args)
+  if args.IsSpecified('enable_autorepair'):
+    enable_autorepair = args.enable_autorepair
+  else:
+    # Node pools using COS support auto repairs, enable it for them by default.
+    # Other node pools using (Ubuntu, custom images) don't support node auto
+    # repairs, attempting to enable autorepair for them will result in API call
+    # failing so don't do it.
+    enable_autorepair = ((args.image_type or '').lower() in ['', 'cos'])
+  flags.WarnForUnspecifiedIpAllocationPolicy(args)
   cluster_ipv4_cidr = args.cluster_ipv4_cidr
   enable_master_authorized_networks = args.enable_master_authorized_networks
   return api_adapter.CreateClusterOptions(
@@ -199,7 +220,7 @@ def ParseCreateOptionsBase(args):
       node_version=args.node_version,
       create_subnetwork=args.create_subnetwork,
       disk_type=args.disk_type,
-      enable_autorepair=args.enable_autorepair,
+      enable_autorepair=enable_autorepair,
       enable_autoscaling=args.enable_autoscaling,
       enable_autoupgrade=args.enable_autoupgrade,
       enable_cloud_endpoints=args.enable_cloud_endpoints,
@@ -253,7 +274,7 @@ class Create(base.CreateCommand):
     flags.AddAddonsFlags(parser)
     flags.AddClusterAutoscalingFlags(parser)
     flags.AddDiskTypeFlag(parser, suppressed=True)
-    flags.AddEnableAutoRepairFlag(parser)
+    flags.AddEnableAutoRepairFlag(parser, for_create=True)
     flags.AddEnableKubernetesAlphaFlag(parser)
     flags.AddEnableLegacyAuthorizationFlag(parser)
     flags.AddIPAliasFlags(parser)
@@ -364,7 +385,7 @@ class CreateBeta(Create):
     flags.AddAddonsFlags(parser)
     flags.AddClusterAutoscalingFlags(parser)
     flags.AddDiskTypeFlag(parser)
-    flags.AddEnableAutoRepairFlag(parser)
+    flags.AddEnableAutoRepairFlag(parser, for_create=True)
     flags.AddEnableBinAuthzFlag(parser, hidden=True)
     flags.AddEnableKubernetesAlphaFlag(parser)
     flags.AddEnableLegacyAuthorizationFlag(parser)
@@ -383,8 +404,9 @@ class CreateBeta(Create):
     flags.AddClusterNodeIdentityFlags(parser)
     flags.AddPrivateClusterFlags(parser, hidden=False)
     flags.AddEnableStackdriverKubernetesFlag(parser)
-    flags.AddTpuFlags(parser, hidden=True)
+    flags.AddTpuFlags(parser, hidden=False)
     flags.AddAutoprovisioningFlags(parser, hidden=True)
+    flags.AddVerticalPodAutoscalingFlag(parser, hidden=True)
 
   def ParseCreateOptions(self, args):
     ops = ParseCreateOptionsBase(args)
@@ -406,6 +428,7 @@ class CreateBeta(Create):
     ops.enable_binauthz = args.enable_binauthz
     ops.enable_tpu = args.enable_tpu
     ops.tpu_ipv4_cidr = args.tpu_ipv4_cidr
+    ops.enable_vertical_pod_autoscaling = args.enable_vertical_pod_autoscaling
     return ops
 
 
@@ -419,11 +442,11 @@ class CreateAlpha(Create):
     group = parser.add_mutually_exclusive_group()
     _AddAdditionalZonesFlag(group, deprecated=True)
     flags.AddNodeLocationsFlag(group)
-    flags.AddAddonsFlags(parser)
+    flags.AddAlphaAddonsFlags(parser)
     flags.AddClusterAutoscalingFlags(parser)
     flags.AddDiskTypeFlag(parser)
     flags.AddMaxPodsPerNodeFlag(parser)
-    flags.AddEnableAutoRepairFlag(parser)
+    flags.AddEnableAutoRepairFlag(parser, for_create=True)
     flags.AddEnableBinAuthzFlag(parser, hidden=True)
     flags.AddEnableKubernetesAlphaFlag(parser)
     flags.AddEnableLegacyAuthorizationFlag(parser)
@@ -446,6 +469,9 @@ class CreateAlpha(Create):
     flags.AddTpuFlags(parser, hidden=False)
     flags.AddEnableStackdriverKubernetesFlag(parser)
     flags.AddManagedPodIdentityFlag(parser)
+    flags.AddResourceUsageBigqueryDatasetFlag(parser)
+    flags.AddAuthenticatorSecurityGroupFlags(parser)
+    flags.AddVerticalPodAutoscalingFlag(parser, hidden=True)
 
   def ParseCreateOptions(self, args):
     ops = ParseCreateOptionsBase(args)
@@ -470,5 +496,8 @@ class CreateAlpha(Create):
     ops.enable_stackdriver_kubernetes = args.enable_stackdriver_kubernetes
     ops.default_max_pods_per_node = args.default_max_pods_per_node
     ops.enable_managed_pod_identity = args.enable_managed_pod_identity
-    flags.ValidateIstioConfigCreateArgs(args.istio_config, args.addons)
+    ops.resource_usage_bigquery_dataset = args.resource_usage_bigquery_dataset
+    ops.security_group = args.security_group
+    flags.ValidateIstioConfigArgs(args.istio_config, args.addons)
+    ops.enable_vertical_pod_autoscaling = args.enable_vertical_pod_autoscaling
     return ops
