@@ -15,7 +15,9 @@
 """Update cluster command."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 from apitools.base.py import exceptions as apitools_exceptions
 
 from googlecloudsdk.api_lib.container import api_adapter
@@ -81,7 +83,6 @@ def _AddMutuallyExclusiveArgs(mutex_group, release_track):
             api_adapter.HPA: _ParseAddonDisabled,
             api_adapter.DASHBOARD: _ParseAddonDisabled,
             api_adapter.NETWORK_POLICY: _ParseAddonDisabled,
-            api_adapter.ISTIO: _ParseAddonDisabled,
         }),
         dest='disable_addons',
         metavar='ADDON=ENABLED|DISABLED',
@@ -89,13 +90,11 @@ def _AddMutuallyExclusiveArgs(mutex_group, release_track):
 {hpa}=ENABLED|DISABLED
 {ingress}=ENABLED|DISABLED
 {dashboard}=ENABLED|DISABLED
-{istio}=ENABLED|DISABLED
 {network_policy}=ENABLED|DISABLED""".format(
     hpa=api_adapter.HPA,
     ingress=api_adapter.INGRESS,
     dashboard=api_adapter.DASHBOARD,
-    network_policy=api_adapter.NETWORK_POLICY,
-    istio=api_adapter.ISTIO,))
+    network_policy=api_adapter.NETWORK_POLICY))
 
   else:
     mutex_group.add_argument(
@@ -422,6 +421,7 @@ class UpdateBeta(Update):
     flags.AddPodSecurityPolicyFlag(group)
     flags.AddEnableBinAuthzFlag(group, hidden=True)
     flags.AddAutoprovisioningFlags(group, hidden=True)
+    flags.AddVerticalPodAutoscalingFlag(group, hidden=True)
 
   def ParseUpdateOptions(self, args, locations):
     opts = container_command_util.ParseUpdateOptionsBase(args, locations)
@@ -434,6 +434,7 @@ class UpdateBeta(Update):
     opts.max_memory = args.max_memory
     opts.min_accelerator = args.min_accelerator
     opts.max_accelerator = args.max_accelerator
+    opts.enable_vertical_pod_autoscaling = args.enable_vertical_pod_autoscaling
     return opts
 
 
@@ -465,7 +466,8 @@ class UpdateAlpha(Update):
     flags.AddMaintenanceWindowFlag(group, add_unset_text=True)
     flags.AddPodSecurityPolicyFlag(group)
     flags.AddEnableBinAuthzFlag(group, hidden=True)
-    flags.AddIstioConfigFlag(parser)
+    flags.AddResourceUsageBigqueryDatasetFlag(group, add_clear_flag=True)
+    flags.AddVerticalPodAutoscalingFlag(group, hidden=True)
 
   def ParseUpdateOptions(self, args, locations):
     opts = container_command_util.ParseUpdateOptionsBase(args, locations)
@@ -478,6 +480,8 @@ class UpdateAlpha(Update):
     opts.max_accelerator = args.max_accelerator
     opts.enable_pod_security_policy = args.enable_pod_security_policy
     opts.enable_binauthz = args.enable_binauthz
-    opts.istio_config = args.istio_config
-    flags.ValidateIstioConfigUpdateArgs(args.istio_config, args.disable_addons)
+    opts.resource_usage_bigquery_dataset = args.resource_usage_bigquery_dataset
+    opts.clear_resource_usage_bigquery_dataset = \
+        args.clear_resource_usage_bigquery_dataset
+    opts.enable_vertical_pod_autoscaling = args.enable_vertical_pod_autoscaling
     return opts
