@@ -15,6 +15,7 @@
 """List tags command."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
 
 import heapq
@@ -32,6 +33,7 @@ from googlecloudsdk.core import http
 _DEFAULT_KINDS = [
     'BUILD_DETAILS',
     'IMAGE_BASIS',
+    'DISCOVERY',
 ]
 # How many images for which to report vulnerabilities, by default. These are
 # always the most recent images, regardless of sorting.
@@ -48,7 +50,8 @@ _TAGS_FORMAT = """
         BUILD_DETAILS.buildDetails.provenance.sourceProvenance.context.cloudRepo.revisionId.notnull().list().slice(:8).join(''):optional:label=GIT_SHA,
         vuln_counts.list():optional:label=VULNERABILITIES,
         IMAGE_BASIS.derivedImage.sort(distance).map().extract(baseResourceUrl).slice(:1).map().list().list().split('//').slice(1:).list().split('@').slice(:1).list():optional:label=FROM,
-        BUILD_DETAILS.buildDetails.provenance.id.notnull().list():optional:label=BUILD
+        BUILD_DETAILS.buildDetails.provenance.id.notnull().list():optional:label=BUILD,
+        DISCOVERY[0].discovered.analysisStatus:optional:label=VULNERABILITY_SCAN_STATUS
     )
 """
 
@@ -144,7 +147,7 @@ class ListTagsALPHA(ListTagsGAandBETA, base.ListCommand):
     parser.add_argument(
         '--show-occurrences',
         action='store_true',
-        default=False,
+        default=True,
         help='Whether to show summaries of the various Occurrence types.')
     parser.add_argument(
         '--occurrence-filter',
