@@ -15,10 +15,12 @@
 """The command group for Cloud Datastore indexes."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 from googlecloudsdk.calliope import base
 
 
-@base.ReleaseTracks(base.ReleaseTrack.BETA)
+@base.ReleaseTracks(base.ReleaseTrack.BETA, base.ReleaseTrack.ALPHA)
 class Indexes(base.Group):
   """Manage Cloud Datastore indexes."""
