@@ -14,20 +14,39 @@
 # limitations under the License.
 
 """Creates or updates a Google Cloud Function."""
+
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 from googlecloudsdk.api_lib.compute import utils
+from googlecloudsdk.api_lib.functions import env_vars as env_vars_api_util
 from googlecloudsdk.api_lib.functions import util as api_util
 from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.functions import flags
+from googlecloudsdk.command_lib.functions.deploy import env_vars_util
 from googlecloudsdk.command_lib.functions.deploy import labels_util
 from googlecloudsdk.command_lib.functions.deploy import source_util
 from googlecloudsdk.command_lib.functions.deploy import trigger_util
 from googlecloudsdk.command_lib.util.args import labels_util as args_labels_util
+from googlecloudsdk.command_lib.util.args import map_util
 from googlecloudsdk.core import log
 
 
-def _Run(args, enable_runtime=False):
+def _ApplyEnvVarsArgsToFunction(function, args):
+  updated_fields = []
+  old_env_vars = env_vars_api_util.GetFunctionEnvVarsAsDict(function)
+  env_var_flags = map_util.GetMapFlagsFromArgs('env-vars', args)
+  new_env_vars = map_util.ApplyMapFlags(old_env_vars, **env_var_flags)
+  if old_env_vars != new_env_vars:
+    function.environmentVariables = env_vars_api_util.DictToEnvVarsProperty(
+        new_env_vars)
+    updated_fields.append('environmentVariables')
+  return updated_fields
+
+
+def _Run(args, track=None, enable_runtime=False, enable_max_instances=False,
+         enable_connected_vpc=False, enable_env_vars=False):
   """Run a function deployment with the given args."""
   # Check for labels that start with `deployment`, which is not allowed.
   labels_util.CheckNoDeploymentLabels('--remove-labels', args.remove_labels)
@@ -45,7 +64,7 @@ def _Run(args, enable_runtime=False):
   function_ref = args.CONCEPTS.name.Parse()
   function_url = function_ref.RelativeName()
 
-  messages = api_util.GetApiMessagesModule()
+  messages = api_util.GetApiMessagesModule(track)
 
   # Get an existing function or create a new one.
   function = api_util.GetFunction(function_url)
@@ -77,6 +96,16 @@ def _Run(args, enable_runtime=False):
     if args.IsSpecified('runtime'):
       function.runtime = args.runtime
       updated_fields.append('runtime')
+  if enable_max_instances:
+    if (args.IsSpecified('max_instances') or
+        args.IsSpecified('clear_max_instances')):
+      max_instances = 0 if args.clear_max_instances else args.max_instances
+      function.maxInstances = max_instances
+      updated_fields.append('maxInstances')
+  if enable_connected_vpc:
+    if args.connected_vpc:
+      function.network = args.connected_vpc
+      updated_fields.append('network')
 
   # Populate trigger properties of function based on trigger args.
   if args.trigger_http:
@@ -111,6 +140,9 @@ def _Run(args, enable_runtime=False):
                                    args.remove_labels, args.clear_labels):
     updated_fields.append('labels')
 
+  if enable_env_vars:
+    updated_fields.extend(_ApplyEnvVarsArgsToFunction(function, args))
+
   if is_new_function:
     return api_util.CreateFunction(function,
                                    function_ref.Parent().RelativeName())
@@ -119,7 +151,7 @@ def _Run(args, enable_runtime=False):
   log.status.Print('Nothing to update.')
 
 
-@base.ReleaseTracks(base.ReleaseTrack.BETA, base.ReleaseTrack.GA)
+@base.ReleaseTracks(base.ReleaseTrack.GA)
 class Deploy(base.Command):
   """Create or update a Google Cloud Function."""
 
@@ -145,7 +177,23 @@ class Deploy(base.Command):
     flags.AddTriggerFlagGroup(parser)
 
   def Run(self, args):
-    return _Run(args)
+    return _Run(args, track=self.ReleaseTrack())
+
+
+@base.ReleaseTracks(base.ReleaseTrack.BETA)
+class DeployBeta(base.Command):
+  """Create or update a Google Cloud Function."""
+
+  @staticmethod
+  def Args(parser):
+    """Register flags for this command."""
+    Deploy.Args(parser)
+    flags.AddRuntimeFlag(parser)
+    env_vars_util.AddUpdateEnvVarsFlags(parser)
+
+  def Run(self, args):
+    return _Run(args, track=self.ReleaseTrack(), enable_runtime=True,
+                enable_env_vars=True)
 
 
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
@@ -157,6 +205,11 @@ class DeployAlpha(base.Command):
     """Register flags for this command."""
     Deploy.Args(parser)
     flags.AddRuntimeFlag(parser)
+    env_vars_util.AddUpdateEnvVarsFlags(parser)
+    flags.AddMaxInstancesFlag(parser)
+    flags.AddConnectedVPCFlag(parser)
 
   def Run(self, args):
-    return _Run(args, enable_runtime=True)
+    return _Run(args, track=self.ReleaseTrack(), enable_runtime=True,
+                enable_max_instances=True, enable_connected_vpc=True,
+                enable_env_vars=True)
