@@ -28,7 +28,8 @@ from googlecloudsdk.command_lib.sql import flags
 from googlecloudsdk.command_lib.sql import import_util
 
 
-@base.ReleaseTracks(base.ReleaseTrack.GA, base.ReleaseTrack.BETA)
+@base.ReleaseTracks(base.ReleaseTrack.GA, base.ReleaseTrack.BETA,
+                    base.ReleaseTrack.ALPHA)
 class Sql(base.Command):
   """Imports data into a Cloud SQL instance from a SQL dump file.
 
