@@ -15,7 +15,9 @@
 """`gcloud tasks queues purge` command."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 from googlecloudsdk.api_lib.tasks import queues
 from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.tasks import flags
@@ -24,7 +26,6 @@ from googlecloudsdk.core import log
 from googlecloudsdk.core.console import console_io
 
 
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
 class Purge(base.Command):
   """Purge a queue by deleting all of its tasks.
 
