@@ -15,7 +15,9 @@
 """`gcloud tasks queues remove-iam-policy-binding` command."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 from googlecloudsdk.api_lib.tasks import queues
 from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.iam import iam_util
@@ -24,7 +26,6 @@ from googlecloudsdk.command_lib.tasks import parsers
 from googlecloudsdk.core import log
 
 
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
 class RemoveIamPolicyBinding(base.Command):
   """Remove an IAM policy binding from a queue's access policy."""
 
